@@ -164,6 +164,8 @@ main(int argc, char *argv[]) {
 	if (open_max == 0)
 		open_max = 65536;
 #elif defined(_MACOS_PORT)
+	if (getrlimit(RLIMIT_NOFILE, &rl) == -1)
+		err(1, "getrlimit");
 	/* guard against unrealistic replies */
 	open_max = min(65536, (unsigned)rl.rlim_cur);
 	if (open_max == 0)
@@ -416,7 +418,7 @@ run_utility(char *argv[]) {
 	char **new_argv;
 	char *p, *arg_buf;
 	int argc;
-	int stdin_pipe[2];
+	int stdin_pipe[2] = {0, 0};
 
 	if (restart_opt == 1) {
 		terminate_utility();
@@ -586,7 +588,6 @@ watch_loop(int kq, char *argv[]) {
 	struct stat sb;
 	char c;
 	struct termios character_tty;
-	char *trace_message;
 
 	leading_edge = files[0]; /* default */
 	if (postpone_opt == 0)
@@ -667,7 +668,6 @@ main:
 	}
 
 	for (i=0; i<nev && reopen_only == 0; i++) {
-		trace_message = "";
 
 		if (evList[i].filter != EVFILT_VNODE)
 			continue;
@@ -689,27 +689,30 @@ main:
 			if (file->mode != sb.st_mode) {
 			    do_exec = 1;
 			    file->mode = sb.st_mode;
-			    trace_message = "mode changed";
 			}
 			/* Possible on Linux when a running binary is unlinked */
 			if (file->ino != sb.st_ino) {
 			    do_exec = 1;
 			    file->ino = sb.st_ino;
-			    trace_message = "inode changed";
 			}
 		}
 		else if (evList[i].fflags & NOTE_ATTRIB)
 			continue;
 
-		if ((file->is_dir == 0) && (leading_edge_set == 0)) {
+		if ((leading_edge_set == 0) &&
+			    (file->is_dir == 0) &&
+			    (do_exec == 1)) {
 			leading_edge = file;
 			leading_edge_set = 1;
 		}
 
 		if (getenv("EV_TRACE")) {
-			fprintf(stderr, "EVFILT_VNODE: %d/%d: "
-			    "fflags: 0x%x %s\n", i, nev, evList[i].fflags,
-			    trace_message);
+			fprintf(stderr, "%d/%d: fflags: 0x%x %s %o %s\n",
+			    i, nev,
+			    evList[i].fflags,
+			    file->is_dir ? "d" : "r",
+			    file->mode,
+			    file->fn);
 		}
 	}
 
